@@ -91,7 +91,7 @@ from nucypher.crypto.powers import (
 )
 from nucypher.crypto.signing import InvalidSignature
 from nucypher.datastore.datastore import DatastoreTransactionError, RecordNotFound
-from nucypher.datastore.models import PolicyArrangement, TreasureMap as DatastoreTreasureMap
+from nucypher.datastore.queries import find_expired_policies, find_expired_treasure_maps
 from nucypher.network.exceptions import NodeSeemsToBeDown
 from nucypher.network.middleware import RestMiddleware
 from nucypher.network.nodes import NodeSprout, Teacher
@@ -124,7 +124,7 @@ class Alice(Character, BlockchainPolicyAuthor):
 
                  # Policy Value
                  rate: int = None,
-                 duration_periods: int = None,
+                 payment_periods: int = None,
 
                  # Policy Storage
                  store_policy_credentials: bool = None,
@@ -175,7 +175,7 @@ class Alice(Character, BlockchainPolicyAuthor):
                                             transacting_power=self.transacting_power,
                                             registry=self.registry,
                                             rate=rate,
-                                            duration_periods=duration_periods)
+                                            payment_periods=payment_periods)
 
         self.log = Logger(self.__class__.__name__)
         if is_me:
@@ -265,7 +265,7 @@ class Alice(Character, BlockchainPolicyAuthor):
     def generate_policy_parameters(self,
                                    m: int = None,
                                    n: int = None,
-                                   duration_periods: int = None,
+                                   payment_periods: int = None,
                                    expiration: maya.MayaDT = None,
                                    *args, **kwargs
                                    ) -> dict:
@@ -273,23 +273,31 @@ class Alice(Character, BlockchainPolicyAuthor):
         Construct policy creation from parameters or overrides.
         """
 
-        if not duration_periods and not expiration:
-            raise ValueError("Policy end time must be specified as 'expiration' or 'duration_periods', got neither.")
+        if not payment_periods and not expiration:
+            raise ValueError("Policy end time must be specified as 'expiration' or 'payment_periods', got neither.")
 
         # Merge injected and default params.
         m = m or self.m
         n = n or self.n
         base_payload = dict(m=m, n=n, expiration=expiration)
 
-        # Calculate Policy Rate and Value
-        if not self.federated_only:
+        if self.federated_only:
+            if not expiration:
+                raise TypeError("For a federated policy, you must specify expiration (payment_periods don't count).")
+            if expiration <= maya.now():
+                raise ValueError(f'Expiration must be in the future ({expiration}).')
+        else:
+            blocktime = maya.MayaDT(self.policy_agent.blockchain.get_blocktime())
+            if expiration and (expiration <= blocktime):
+                raise ValueError(f'Expiration must be in the future ({expiration} is earlier than blocktime {blocktime}).')
+
+            # Calculate Policy Rate and Value
             payload = super().generate_policy_parameters(number_of_ursulas=n,
-                                                         duration_periods=duration_periods,
+                                                         payment_periods=payment_periods,
                                                          expiration=expiration,
                                                          *args, **kwargs)
             base_payload.update(payload)
-        elif not expiration:
-            raise TypeError("For a federated policy, you must specify expiration (duration_periods don't count).")
+
         return base_payload
 
     def _check_grant_requirements(self, policy):
@@ -1221,10 +1229,7 @@ class Ursula(Teacher, Character, Worker):
         """Deletes all expired arrangements, kfrags, and treasure maps in the datastore."""
         now = maya.MayaDT.from_datetime(datetime.fromtimestamp(self._datastore_pruning_task.clock.seconds()))
         try:
-            with self.datastore.query_by(PolicyArrangement,
-                                         filter_field='expiration',
-                                         filter_func=lambda expiration: expiration <= now,
-                                         writeable=True) as expired_policies:
+            with find_expired_policies(self.datastore, now) as expired_policies:
                 for policy in expired_policies:
                     policy.delete()
                 result = len(expired_policies)
@@ -1237,10 +1242,7 @@ class Ursula(Teacher, Character, Worker):
                 self.log.debug(f"Pruned {result} policy arrangements.")
 
         try:
-            with self.datastore.query_by(DatastoreTreasureMap,
-                                         filter_field='expiration',
-                                         filter_func=lambda expiration: expiration <= now,
-                                         writeable=True) as expired_treasure_maps:
+            with find_expired_treasure_maps(self.datastore, now) as expired_treasure_maps:
                 for treasure_map in expired_treasure_maps:
                     treasure_map.delete()
                 result = len(expired_treasure_maps)
