@@ -54,7 +54,8 @@ from nucypher.cli.options import (
     option_registry_filepath,
     option_signer_uri,
     option_teacher_uri,
-    option_lonely, option_max_gas_price
+    option_lonely,
+    option_max_gas_price
 )
 from nucypher.cli.painting.help import paint_new_installation_help
 from nucypher.cli.painting.policies import paint_single_card
@@ -69,7 +70,7 @@ from nucypher.network.middleware import RestMiddleware
 from nucypher.policy.identity import Card
 
 option_pay_with = click.option('--pay-with', help="Run with a specified account", type=EIP55_CHECKSUM_ADDRESS)
-option_duration_periods = click.option('--duration-periods', help="Policy duration in periods", type=click.INT)
+option_payment_periods = click.option('--payment-periods', help="Policy payment periods", type=click.INT)
 
 
 class AliceConfigOptions:
@@ -128,6 +129,10 @@ class AliceConfigOptions:
             )
 
         else:
+            if not config_file:
+                config_file = select_config_file(emitter=emitter,
+                                                 checksum_address=self.pay_with,
+                                                 config_class=AliceConfiguration)
             try:
                 return AliceConfiguration.from_configuration_file(
                     emitter=emitter,
@@ -172,13 +177,13 @@ class AliceFullConfigOptions:
 
     __option_name__ = 'full_config_options'
 
-    def __init__(self, config_options, poa: bool, light: bool, m: int, n: int, duration_periods: int):
+    def __init__(self, config_options, poa: bool, light: bool, m: int, n: int, payment_periods: int):
         self.config_options = config_options
         self.poa = poa
         self.light = light
         self.m = m
         self.n = n
-        self.duration_periods = duration_periods
+        self.payment_periods = payment_periods
 
     def generate_config(self, emitter: StdoutEmitter, config_root: str) -> AliceConfiguration:
 
@@ -213,7 +218,7 @@ class AliceFullConfigOptions:
             light=self.light,
             m=self.m,
             n=self.n,
-            duration_periods=self.duration_periods)
+            payment_periods=self.payment_periods)
 
     def get_updates(self) -> dict:
         opts = self.config_options
@@ -227,7 +232,7 @@ class AliceFullConfigOptions:
                        light=self.light,
                        m=self.m,
                        n=self.n,
-                       duration_periods=self.duration_periods)
+                       payment_periods=self.payment_periods)
         # Depends on defaults being set on Configuration classes, filtrates None values
         updates = {k: v for k, v in payload.items() if v is not None}
         return updates
@@ -240,7 +245,7 @@ group_full_config_options = group_options(
     light=option_light,
     m=option_m,
     n=option_n,
-    duration_periods=option_duration_periods
+    payment_periods=option_payment_periods
 )
 
 
@@ -272,7 +277,6 @@ class AliceCharacterOptions:
             click.get_current_context().exit(1)
 
 
-
 group_character_options = group_options(
     AliceCharacterOptions,
     config_options=group_config_options,
@@ -297,7 +301,8 @@ def init(general_config, full_config_options, config_root):
     if not config_root:
         config_root = general_config.config_root
     new_alice_config = full_config_options.generate_config(emitter, config_root)
-    paint_new_installation_help(emitter, new_configuration=new_alice_config)
+    filepath = new_alice_config.to_configuration_file()
+    paint_new_installation_help(emitter, new_configuration=new_alice_config, filepath=filepath)
 
 
 @alice.command()
