@@ -17,8 +17,7 @@ along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
 import maya
 
 from nucypher.config.constants import SEEDNODES
-from nucypher.datastore.datastore import RecordNotFound
-from nucypher.datastore.models import Workorder
+from nucypher.datastore.queries import get_work_orders
 
 
 def build_fleet_state_status(ursula) -> str:
@@ -42,11 +41,8 @@ def paint_node_status(emitter, ursula, start_time):
     # Build FleetState status line
     fleet_state = build_fleet_state_status(ursula=ursula)
 
-    try:
-        with ursula.datastore.query_by(Workorder) as work_orders:
-            num_work_orders = len(work_orders)
-    except RecordNotFound:
-        num_work_orders = 0
+    work_orders = get_work_orders(ursula.datastore)
+    num_work_orders = len(work_orders)
 
     stats = ['⇀URSULA {}↽'.format(ursula.nickname.icon),
              '{}'.format(ursula),
