@@ -17,10 +17,13 @@
 
 
 import json
-
 import os
 import re
 from abc import ABC, abstractmethod
+from decimal import Decimal
+from tempfile import TemporaryDirectory
+from typing import Union, Callable, Optional, List
+
 from constant_sorrow.constants import (
     UNKNOWN_VERSION,
     UNINITIALIZED_CONFIGURATION,
@@ -30,12 +33,7 @@ from constant_sorrow.constants import (
     DEVELOPMENT_CONFIGURATION,
     LIVE_CONFIGURATION
 )
-
-
-from decimal import Decimal
 from eth_utils.address import is_checksum_address
-from tempfile import TemporaryDirectory
-from typing import Union, Callable, Optional, List
 from umbral.signing import Signature
 
 from nucypher.blockchain.eth.interfaces import BlockchainInterfaceFactory
@@ -268,7 +266,7 @@ class BaseConfiguration(ABC):
         """Reads `filepath` and returns the deserialized JSON payload dict."""
         with open(filepath, 'r') as file:
             raw_contents = file.read()
-            payload = cls.deserialize(raw_contents)
+            payload = cls.deserialize(raw_contents, payload_label=filepath)
         return payload
 
     def _write_configuration_file(self, filepath: str, override: bool = False) -> str:
@@ -287,16 +285,17 @@ class BaseConfiguration(ABC):
         return serialized_payload
 
     @classmethod
-    def deserialize(cls, payload: str, deserializer=json.loads) -> dict:
+    def deserialize(cls, payload: str, deserializer=json.loads, payload_label: Optional[str] = None) -> dict:
         """Returns the JSON deserialized content of `payload`"""
         deserialized_payload = deserializer(payload)
         version = deserialized_payload.pop('version', UNKNOWN_VERSION)
         if version != cls.VERSION:
-            raise cls.OldVersion(f"Configuration file is the wrong version "
+            label = f"'{payload_label}' " if payload_label else ""
+            raise cls.OldVersion(f"Configuration {label}is the wrong version "
                                  f"Expected version {cls.VERSION}; Got version {version}")
         return deserialized_payload
 
-    def update(self, filepath: str = None, modifier: str = None, **updates) -> None:
+    def update(self, filepath: str = None, **updates) -> None:
         for field, value in updates.items():
             try:
                 getattr(self, field)
@@ -304,7 +303,8 @@ class BaseConfiguration(ABC):
                 raise self.ConfigurationError(f"Cannot update '{field}'. It is an invalid configuration field.")
             else:
                 setattr(self, field, value)
-        self.to_configuration_file(filepath=filepath, modifier=modifier, override=True)
+        # just write the configuration file, file exists and we are overriding
+        self._write_configuration_file(filepath=filepath, override=True)
 
 
 class CharacterConfiguration(BaseConfiguration):
@@ -523,7 +523,6 @@ class CharacterConfiguration(BaseConfiguration):
 
     @classmethod
     def checksum_address_from_filepath(cls, filepath: str) -> str:
-
         pattern = re.compile(r'''
                              (^\w+)-
                              (0x{1}         # Then, 0x the start of the string, exactly once
@@ -536,22 +535,11 @@ class CharacterConfiguration(BaseConfiguration):
 
         if match:
             character_name, checksum_address = match.groups()
-
         else:
             # Extract from default by "peeking" inside the configuration file.
             default_name = cls.generate_filename()
             if filename == default_name:
                 checksum_address = cls.peek(filepath=filepath, field='checksum_address')
-
-                ###########
-                # TODO: Cleanup and deprecate worker_address in config files, leaving only checksum_address
-                from nucypher.config.characters import UrsulaConfiguration
-                if isinstance(cls, UrsulaConfiguration):
-                    federated = bool(cls.peek(filepath=filepath, field='federated_only'))
-                    if not federated:
-                        checksum_address = cls.peek(filepath=cls.filepath, field='worker_address')
-                ###########
-
             else:
                 raise ValueError(f"Cannot extract checksum from filepath '{filepath}'")
 
@@ -565,14 +553,14 @@ class CharacterConfiguration(BaseConfiguration):
 
         Warning: This method allows mutation and may result in an inconsistent configuration.
         """
-        return super().update(modifier=self.checksum_address, filepath=self.config_file_location, **kwargs)
+        # config file should exist and we we override -> no need for modifier
+        return super().update(filepath=self.config_file_location, **kwargs)
 
     @classmethod
     def generate(cls, password: str, *args, **kwargs):
-        """Shortcut: Hook-up a new initial installation and write configuration file to the disk"""
+        """Shortcut: Hook-up a new initial installation and configuration."""
         node_config = cls(dev_mode=False, *args, **kwargs)
         node_config.initialize(password=password)
-        node_config.to_configuration_file()
         return node_config
 
     def cleanup(self) -> None:
